==> haskell-wreq-0.5.4.3-187-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.3
visibility:           public
id:                   wreq-0.5.4.3-98odQauSYxN5sBNz7e3grB
key:                  wreq-0.5.4.3-98odQauSYxN5sBNz7e3grB
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  01a70b4958fe4442f6026e20b6c76ec9
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.3-98odQauSYxN5sBNz7e3grB
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW
    authenticate-oauth-1.7-4hypDGjrBZ0KkVavXjHd1S base-4.17.2.1
    base16-bytestring-1.0.2.0-ASFphLrgXvi67bm2qxzorY
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7
    containers-0.6.7 crypton-1.0.3-16cGkRi6FF0JFIvaY823Of
    exceptions-0.10.5 ghc-prim-0.9.1
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lens-aeson-1.2.3-IQCA0tfGZ9IGSPqjYgAIyQ
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    psqueues-0.2.8.2-G1qNYYyKlMv2YmbUmkz1pg template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.4.3-212-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.3
visibility:           public
id:                   wreq-0.5.4.3-7uUgwYkRhLx510FWSxbTvH
key:                  wreq-0.5.4.3-7uUgwYkRhLx510FWSxbTvH
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  9e78e24ffcee80379181053586b019ba
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.3-7uUgwYkRhLx510FWSxbTvH
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y
    authenticate-oauth-1.7-E6GjDLWImIE9hxsdp0RTdr base-4.17.2.1
    base16-bytestring-1.0.2.0-1Uz6oHjhPf9KewF5fWee2u
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    containers-0.6.7 crypton-1.0.4-AGWvxb3uQebCjfbnRIxIRG
    exceptions-0.10.5 ghc-prim-0.9.1
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lens-aeson-1.2.3-9hOzJLNvQbOAUIoSWVRISn
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    psqueues-0.2.8.2-Faq2x2S7WnDAAtgzdAODJJ template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
